@@ -1,13 +1,13 @@
 import pandas as pd
 import numpy as np
-import os
-from os import path
+import pkg_resources
+
 from scipy.stats import spearmanr
 import statistics
 
-data_dir = path.join(path.dirname(__file__), 'data')
+data_file = pkg_resources.resource_stream(__name__, 'data/val_target_preds.parquet')
 
-VAL_DATA = pd.read_parquet(data_dir + 'val_target_preds.parquet', engine='pyarrow').set_index("id")
+VAL_DATA = pd.read_parquet(data_file, engine='pyarrow').set_index("id")
 
 
 def diagnose(preds_df, TARGET_NAME='target',PREDICTION_NAME='prediction'):
